
// Arduino code for flytrap mechanism that shuts when sensor detects a nearby object
// shuts by rotating the servo motors inward
// light is green when open, red when closing/closed
// waits for a specified period of time, then opens back up again and restarts
//

//setup code
int angle = 0; // initialize positional servos at zero degrees
int dt = 10000; // time to stay shut, 10 seconds (10000ms)
float cm = 0; // initialize distance variable
#include <Servo.h> // load servo library
  Servo servo1; // first servo motor
  Servo servo2; // second servo motor

//function for setting up and reading the distance from the ultrasonic sensor
long readUltrasonicDistance(int triggerPin, int echoPin)
{
  pinMode(triggerPin, OUTPUT);  // Clear the trigger
  digitalWrite(triggerPin, LOW);
  delayMicroseconds(2);
  // Sets the trigger pin to HIGH state for 10 microseconds
  digitalWrite(triggerPin, HIGH);
  delayMicroseconds(10);
  digitalWrite(triggerPin, LOW);
  pinMode(echoPin, INPUT);
  // Reads the echo pin, and returns the sound wave travel time in microseconds
  return pulseIn(echoPin, HIGH);
}


void setup()
{
 Serial.begin(9600);
 pinMode(13, OUTPUT); // green light
 pinMode(12, OUTPUT); // red right
 //attach servos to Arduino pins and set both to initial angle
 servo1.attach(11);
 servo2.attach(10);
 servo1.write(angle); 
 servo2.write(angle);
 digitalWrite(11,HIGH); //default light color should be green, red light off
}

void loop()
{

  // Measure the ping time in cm, tells distance to nearest object
  cm = 0.01723 * readUltrasonicDistance(3,6);
                 
 Serial.println(cm); //for testing purposes, print distance to nearest object

  // if an object comes within 5 cm of the sensor, the trap will shut
  if (cm <= 5) { // 
    angle = 180;
    digitalWrite(12, HIGH); // red light on
    digitalWrite(13,LOW); // green light off
    //rotate both servos 180 degrees
    servo1.write(angle);
    servo2.write(angle);
    delay(dt);   //wait 10 sec
    angle = 0; // open trap back up
    servo1.write(angle);
    servo2.write(angle);
    digitalWrite(13,HIGH); // green light on
    digitalWrite(12, LOW); // red light off
    delay(1000); } // avoid reading new data from sensor for 1 sec to allow trap to rotate back open
  else { // make sure angle is always re-initalized at zero if nothing is 5cm away
    angle = 0;
    servo1.write(angle);
    servo2.write(angle); }  
  
}
 
